@@ -4,33 +4,35 @@ import datetime
 from itertools import zip_longest
 from email.utils import getaddresses, parsedate_to_datetime
 from email.header import decode_header, Header
-from typing import AnyStr, Union, Optional, Tuple, Iterable, Any, List, Dict
+from typing import Union, Optional, Tuple, Iterable, Any, List, Dict, Iterator, Sequence
 
 from .consts import SHORT_MONTH_NAMES, MailMessageFlags
-from . import imap_utf7
+from .imap_utf7 import utf7_encode
+
+StrOrBytes = Union[str, bytes]
 
 
-def clean_uids(uid_set: Union[str, Iterable[str]]) -> str:
+def clean_uids(uid_set: Union[str, Iterable[str]]) -> List[str]:
     """
     Prepare set of uid for use in IMAP commands
     uid RE patterns are not strict and allow invalid combinations, but simple. Example: 2,4:7,9,12:*
     :param uid_set:
         str, that is comma separated uids
         Iterable, that contains str uids
-    :return: str - uids, concatenated by a comma
+    :return: list of str - cleaned uids
     """
     # str
     if type(uid_set) is str:
         if re.search(r'^([\d*:]+,)*[\d*:]+$', uid_set):  # *optimization for already good str
-            return uid_set
+            return uid_set.split(',')
         uid_set = uid_set.split(',')
     # check uid types
     for uid in uid_set:
         if type(uid) is not str:
-            raise TypeError('uid "{}" is not string'.format(str(uid)))
+            raise TypeError(f'uid "{str(uid)}" is not string')
         if not re.match(r'^[\d*:]+$', uid.strip()):
-            raise TypeError('Wrong uid: "{}"'.format(uid))
-    return ','.join(i.strip() for i in uid_set)
+            raise TypeError(f'Wrong uid: "{uid}"')
+    return [i.strip() for i in uid_set]
 
 
 def check_command_status(command_result: tuple, exception: type, expected='OK'):
@@ -46,7 +48,7 @@ def check_command_status(command_result: tuple, exception: type, expected='OK'):
         raise exception(command_result=command_result, expected=expected)
 
 
-def decode_value(value: AnyStr, encoding: Optional[str] = None) -> str:
+def decode_value(value: StrOrBytes, encoding: Optional[str] = None) -> str:
     """Converts value to utf-8 encoding"""
     if isinstance(encoding, str):
         encoding = encoding.lower()
@@ -68,16 +70,20 @@ class EmailAddress:
 
     @property
     def full(self):
-        return '{} <{}>'.format(self.name, self.email) if self.name and self.email else self.name or self.email
+        return f'{self.name} <{self.email}>' if self.name and self.email else self.name or self.email
 
     def __repr__(self):
-        return "{}(name={}, email={})".format(
-            self.__class__.__name__, repr(self.name), repr(self.email))
+        return f"{self.__class__.__name__}(name={repr(self.name)}, email={repr(self.email)})"
 
     def __eq__(self, other):
         return all(getattr(self, i) == getattr(other, i) for i in self.__slots__)
 
 
+def remove_non_printable(value: str) -> str:
+    """Remove non-printable character from value"""
+    return ''.join(i for i in value if i.isprintable())
+
+
 def parse_email_addresses(raw_header: Union[str, Header]) -> Tuple[EmailAddress, ...]:
     """
     Parse email addresses from header
@@ -87,7 +93,7 @@ def parse_email_addresses(raw_header: Union[str, Header]) -> Tuple[EmailAddress,
     result = []
     if type(raw_header) is Header:
         raw_header = decode_value(*decode_header(raw_header)[0])
-    for raw_name, email in getaddresses([raw_header.replace('\r\n', '').replace('\n', '')]):
+    for raw_name, email in getaddresses([remove_non_printable(raw_header)]):
         name = decode_value(*decode_header(raw_name)[0]).strip()
         email = email.strip()
         if not (name or email):
@@ -119,7 +125,7 @@ def parse_email_date(value: str) -> datetime.datetime:
         group = match.groupdict()
         day, month, year = group['date'].split()
         time_values = group['time'].split(':')
-        zone_sign = int('{}1'.format(group.get('zone_sign') or '+'))
+        zone_sign = int(f'{group.get("zone_sign") or "+"}1')
         zone = group['zone']
         try:
             return datetime.datetime(
@@ -139,7 +145,7 @@ def parse_email_date(value: str) -> datetime.datetime:
     return datetime.datetime(1900, 1, 1)
 
 
-def quote(value: AnyStr) -> AnyStr:
+def quote(value: StrOrBytes) -> StrOrBytes:
     if isinstance(value, str):
         return '"' + value.replace('\\', '\\\\').replace('"', '\\"') + '"'
     else:
@@ -153,24 +159,12 @@ def pairs_to_dict(items: List[Any]) -> Dict[Any, Any]:
     return dict((items[i * 2], items[i * 2 + 1]) for i in range(len(items) // 2))
 
 
-def chunks(iterable: Iterable[Any], n: int, fill_value: Optional[Any] = None) -> Iterable[Tuple[Any, ...]]:
-    """
-    Group data into fixed-length chunks or blocks
-        [iter(iterable)]*n creates one iterator, repeated n times in the list
-        izip_longest then effectively performs a round-robin of "each" (same) iterator
-    Examples:
-        chunks('ABCDEFGH', 3, '?') --> [('A', 'B', 'C'), ('D', 'E', 'F'), ('G', 'H', '?')]
-        chunks([1, 2, 3, 4, 5], 2) --> [(1, 2), (3, 4), (5, None)]
-    """
-    return zip_longest(*[iter(iterable)] * n, fillvalue=fill_value)
-
-
-def encode_folder(folder: AnyStr) -> bytes:
+def encode_folder(folder: StrOrBytes) -> bytes:
     """Encode folder name"""
     if isinstance(folder, bytes):
         return folder
     else:
-        return quote(imap_utf7.encode(folder))
+        return quote(utf7_encode(folder))
 
 
 def clean_flags(flag_set: Union[str, Iterable[str]]) -> List[str]:
@@ -183,7 +177,7 @@ def clean_flags(flag_set: Union[str, Iterable[str]]) -> List[str]:
     upper_sys_flags = tuple(i.upper() for i in MailMessageFlags.all)
     for flag in flag_set:
         if not type(flag) is str:
-            raise ValueError('Flag - str value expected, but {} received'.format(type(flag_set)))
+            raise ValueError(f'Flag - str value expected, but {type(flag_set)} received')
         if flag.upper() not in upper_sys_flags and flag.startswith('\\'):
             raise ValueError('Non system flag must not start with "\\"')
     return flag_set
@@ -193,3 +187,57 @@ def check_timeout_arg_support(timeout):
     """If timeout arg not supports - raise ValueError"""
     if timeout is not None and sys.version_info.minor < 9:
         raise ValueError('imaplib.IMAP4 timeout argument supported since python 3.9')
+
+
+def replace_html_ct_charset(html: str, new_charset: str) -> str:
+    """Replace charset in META tag with content-type attribute in HTML text"""
+    meta_ct_match = re.search(r'<\s*meta .*?content-type.*?>', html, re.IGNORECASE | re.DOTALL)
+    if meta_ct_match:
+        meta = meta_ct_match.group(0)
+        meta_new = re.sub(
+            pattern=r'charset\s*=\s*[a-zA-Z0-9_:.+-]+',
+            repl=f'charset={new_charset}',
+            string=meta,
+            count=1,
+            flags=re.IGNORECASE
+        )
+        html = html.replace(meta, meta_new)
+    return html
+
+
+def chunked(iterable: Iterable[Any], n: int, fill_value: Optional[Any] = None) -> Iterator[Tuple[Any, ...]]:
+    """
+    Group data into fixed-length chunks or blocks
+        [iter(iterable)]*n creates one iterator, repeated n times in the list
+        izip_longest then effectively performs a round-robin of "each" (same) iterator
+    Examples:
+        chunked('ABCDEFGH', 3, '?') --> [('A', 'B', 'C'), ('D', 'E', 'F'), ('G', 'H', '?')]
+        chunked([1, 2, 3, 4, 5], 2) --> [(1, 2), (3, 4), (5, None)]
+    """
+    return zip_longest(*[iter(iterable)] * n, fillvalue=fill_value)
+
+
+def chunked_crop(seq: Sequence, chunk_size: Optional[int]) -> Iterator[list]:
+    """
+    Yield successive n-sized chunks from seq.
+    Yield seq if chunk_size is False-like
+    :param seq: Sequence to chunks
+    :param chunk_size: chunk size
+    :return: Iterator
+    import pprint
+    pprint.pprint(list(chunked_crop(range(10, 75), 10)))
+    [[10, 11, 12, 13, 14, 15, 16, 17, 18, 19],
+     [20, 21, 22, 23, 24, 25, 26, 27, 28, 29],
+     [30, 31, 32, 33, 34, 35, 36, 37, 38, 39],
+     [40, 41, 42, 43, 44, 45, 46, 47, 48, 49],
+     [50, 51, 52, 53, 54, 55, 56, 57, 58, 59],
+     [60, 61, 62, 63, 64, 65, 66, 67, 68, 69],
+     [70, 71, 72, 73, 74]]
+    """
+    if not chunk_size:
+        yield seq
+        return
+    if chunk_size < 0:
+        raise ValueError('False-like or int>=0 expected')
+    for i in range(0, len(seq), chunk_size):
+        yield seq[i:i + chunk_size]
