@@ -8,7 +8,7 @@ DATA = dict(
     cc=(),
     bcc=(),
     reply_to=(),
-    date=datetime.datetime(2009, 6, 11, 23, 25, 2, tzinfo=datetime.timezone(datetime.timedelta(-1, 61200))),
+    date=datetime.datetime(2009, 6, 11, 23, 25, 2, tzinfo=datetime.timezone(datetime.timedelta(days=-1, seconds=61200))),
     date_str='Thu, 11 Jun 2009 23:25:02 -0700',
     text="From one solid piece of aluminum comes a MacBook Pro that's thin and light, beautifully streamlined, and durable.\r\n",
     html='<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">\r\n<html>\r\n<head>\r\n<body>\r\nFrom one solid piece of aluminum comes a MacBook Pro that\'s thin and light, beautifully streamlined, and durable.<br><a href="http://insideapple.app</body>\r\n</html>\r\n',
