@@ -14,8 +14,8 @@ DATA = dict(
     html='',
     headers={'from': ('"=?Windows-1252?B?Rm9ybWHn428gRnJlbmV0aWtwb2xpcw==?=" <info@formacaofrenetik.info>',), 'to': ('martin@internet.ao, iris@internet.ao, support@maxnet.ao',), 'subject': ('Forma\udce7\udce3o FrenetikPolis: Mega Campanha Final Ver\udce3o | Cursos de Setembro',)},
     attachments=[],
-    from_values=EmailAddress('Formação Frenetikpolis', 'info@formacaofrenetik.info', 'Formação Frenetikpolis <info@formacaofrenetik.info>'),
-    to_values=(EmailAddress('', 'martin@internet.ao', 'martin@internet.ao'), EmailAddress('', 'iris@internet.ao', 'iris@internet.ao'), EmailAddress('', 'support@maxnet.ao', 'support@maxnet.ao')),
+    from_values=EmailAddress(name='Formação Frenetikpolis', email='info@formacaofrenetik.info'),
+    to_values=(EmailAddress(name='', email='martin@internet.ao'), EmailAddress(name='', email='iris@internet.ao'), EmailAddress(name='', email='support@maxnet.ao')),
     cc_values=(),
     bcc_values=(),
     reply_to_values=(),
