@@ -14,8 +14,8 @@ DATA = dict(
     html='',
     headers={'message-id': ('<200201221435.g0MEZP927213@mailman.enron.com>',), 'content-type': ('multipart/related; boundary="_----------=_10117101281980"',), 'mime-version': ('1.0',), 'date': ('Tue, 22 Jan 2002 14:35:28 UT',), 'subject': ('Redacted',), 'to': ('redacted@example.com',), 'from': ('redacted@example.com',), 'return-path': ('redacted@example.com',)},
     attachments=[],
-    from_values=EmailAddress('', 'redacted@example.com', 'redacted@example.com'),
-    to_values=(EmailAddress('', 'redacted@example.com', 'redacted@example.com'),),
+    from_values=EmailAddress(name='', email='redacted@example.com'),
+    to_values=(EmailAddress(name='', email='redacted@example.com'),),
     cc_values=(),
     bcc_values=(),
     reply_to_values=(),
